make SkRSXform singular

bookmaker complains that it doesn't know about SkRSXforms <- plural

Made them singular, made one 'SkRSXform array' since I think that
was the intent, don't know about the other one.

TBR=reed@google.com

Docs-Preview: https://skia.org/?cl=179730
Bug: skia:
Change-Id: I3d2194568a44e8e99995c0ff7b08b1f8b193abe7
Reviewed-on: https://skia-review.googlesource.com/c/179730
Commit-Queue: Cary Clark <caryclark@skia.org>
Auto-Submit: Cary Clark <caryclark@skia.org>
Reviewed-by: Cary Clark <caryclark@skia.org>
diff --git a/include/core/SkTextBlob.h b/include/core/SkTextBlob.h
index 6ead9d4..8a3129b 100644
--- a/include/core/SkTextBlob.h
+++ b/include/core/SkTextBlob.h
@@ -59,7 +59,7 @@
 
         Pass nullptr for intervals to determine the size of the interval array.
 
-        Runs within the blob that contain SkRSXforms are ignored when computing intercepts.
+        Runs within the blob that contain SkRSXform are ignored when computing intercepts.
 
         @param bounds     lower and upper line parallel to the advance
         @param intervals  returned intersections; may be nullptr
@@ -340,7 +340,7 @@
     const RunBuffer& allocRunPos(const SkFont& font, int count,
                                  const SkRect* bounds = nullptr);
 
     // Experimental, RunBuffer.pos points to SkRSXforms
     const RunBuffer& allocRunRSXform(const SkFont& font, int count);
 
 private:
@@ -340,7 +340,7 @@
                                  const SkRect* bounds = nullptr);
 
-    // Experimental, RunBuffer.pos points to SkRSXforms
+    // Experimental, RunBuffer.pos points to SkRSXform array
     const RunBuffer& allocRunRSXform(const SkFont& font, int count);
 